==> cutetube_1.3.1.tar.gz: cutetube-1.3.1/src/maemo5/dailymotionplaylistvideoswindow.cpp <==
#include "dailymotionplaylistvideoswindow.h"
#include "videolistdelegate.h"
#include "dailymotionvideoinfowindow.h"
#include "dailymotionchannelwindow.h"
#include "videoselectionwindow.h"
#include <QMenuBar>
#include <QGridLayout>
#include <QScrollBar>

DailymotionPlaylistVideosWindow::DailymotionPlaylistVideosWindow(Session *session, QSharedPointer<PlaylistItem> playlist, QWidget *parent) :
    StackedWindow(session, parent),
    m_playlist(playlist),
    m_listView(new ListView(this)),
    m_model(new DailymotionVideoListModel(m_session, this)),
    m_addToFavouritesAction(menuBar()->addAction(tr("Add to favourites"), this, SLOT(addVideosToFavourites()))),
    m_addToPlaylistAction(menuBar()->addAction(tr("Add to playlist"), this, SLOT(addVideosToPlaylist()))),
    m_addToQueueAction(menuBar()->addAction(tr("Add to playback queue"), this, SLOT(queueVideos()))),
    m_videoDownloadAction(menuBar()->addAction(tr("Download"), this, SLOT(addVideoDownloads()))),
    m_audioDownloadAction(menuBar()->addAction(tr("Download (audio)"), this, SLOT(addAudioDownloads()))),
    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No videos found")), this)),
    m_titleLabel(new QLabel(QString("<p style='font-size:32px;'>%1</p>").arg(m_playlist.data()->title()))),
    m_descriptionLabel(new QLabel(m_playlist.data()->description().isEmpty() ? tr("No description") : m_playlist.data()->description(), this)),
    m_dateLabel(new QLabel(QString("%1 - %2").arg(m_playlist.data()->date()).arg(m_playlist.data()->artist()), this)),
    m_thumbnail(new ThumbnailLabel(this)),
    m_avatar(new ThumbnailLabel(this)),
    m_separator1(new SeparatorLabel(tr("Description"), this)),
    m_separator2(new SeparatorLabel(QString("-- %1").arg(tr("videos")), this)),
    m_scrollArea(new QScrollArea(this))
{
    setWindowTitle(tr("Playlist"));
    setCentralWidget(m_scrollArea);

    VideoListDelegate *delegate = new VideoListDelegate(m_listView);

    m_listView->setModel(m_model);
    m_listView->setItemDelegate(delegate);
    m_noResultsLabel->hide();
    m_descriptionLabel->setWordWrap(true);
    m_dateLabel->setWordWrap(true);

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QGridLayout *grid = new QGridLayout(scrollWidget);

    m_thumbnail->setInteractive(false);
    m_thumbnail->setFixedSize(160, 120);
    m_avatar->setFixedSize(60, 60);

    grid->setContentsMargins(0, 0, 0, 0);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Maximum), 0, 0);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Maximum), 1, 0);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Maximum), 3, 0);
    grid->addWidget(m_titleLabel, 0, 1, 1, 3, Qt::AlignTop);
    grid->addWidget(m_thumbnail, 1, 1, Qt::AlignTop);
    grid->addWidget(m_avatar, 1, 2, Qt::AlignTop);
    grid->addWidget(m_dateLabel, 1, 3, Qt::AlignTop);
    grid->addWidget(m_separator1, 2, 0, 1, 4);
    grid->addWidget(m_descriptionLabel, 3, 1, 1, 3);
    grid->addWidget(m_separator2, 4, 0, 1, 4);
    grid->addWidget(m_listView, 5, 0, 1, 4);

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);
    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

    connect(m_model, SIGNAL(loadingChanged()), this, SLOT(onLoadingChanged()));
    connect(delegate, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
    connect(delegate, SIGNAL(play(QModelIndex)), this, SLOT(playVideo(QModelIndex)));
    connect(m_avatar, SIGNAL(clicked()), this, SLOT(showUserChannel()));

    m_model->getPlaylistVideos(m_playlist.data()->playlistId());

    setThumbnails();
    setMenuActions();
    onOrientationChanged();
}

void DailymotionPlaylistVideosWindow::setLandscapeLayout() {
    m_noResultsLabel->setFixedSize(m_scrollArea->size());
    m_scrollArea->widget()->setMaximumWidth(800);
}

void DailymotionPlaylistVideosWindow::setPortraitLayout() {
    m_noResultsLabel->setFixedSize(m_scrollArea->size());
    m_scrollArea->widget()->setMaximumWidth(480);
}

void DailymotionPlaylistVideosWindow::setThumbnails() {
    QImage thumbnail;

    if (m_model->rowCount() > 0) {
        thumbnail = m_session->thumbnailCache()->thumbnail(m_model->get(0).data()->thumbnailUrl());
    }

    QImage avatar = m_session->thumbnailCache()->thumbnail(m_playlist.data()->artistAvatarUrl(), QSize(60, 60));

    if ((thumbnail.isNull()) || (avatar.isNull())) {
        connect(m_session->thumbnailCache(), SIGNAL(thumbnailReady()), this, SLOT(setThumbnails()));
    }
    else {
        disconnect(m_session->thumbnailCache(), SIGNAL(thumbnailReady()), this, SLOT(setThumbnails()));
    }
    if (!thumbnail.isNull()) {
        m_thumbnail->setImage(thumbnail);
    }
    if (!avatar.isNull()) {
        m_avatar->setImage(avatar);
    }
}

void DailymotionPlaylistVideosWindow::setMenuActions() {
    bool signedIn = m_session->dailymotion()->userSignedIn();

    m_addToFavouritesAction->setEnabled(signedIn);
    m_addToPlaylistAction->setEnabled(signedIn);
}

void DailymotionPlaylistVideosWindow::onLoadingChanged() {
    toggleBusy(m_model->loading());
    m_noResultsLabel->setVisible((!m_model->loading()) && (m_model->rowCount() == 0));

    if (!m_model->loading()) {
        m_separator2->setText(QString("%1 %2").arg(m_model->rowCount()).arg(tr("videos")));

        if (m_model->rowCount() > 0) {
            m_listView->setFixedHeight(m_model->rowCount() * 150);
            setThumbnails();
        }
    }
}

void DailymotionPlaylistVideosWindow::addVideosToFavourites() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Add to favourites"), SLOT(addVideosToFavourites()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::addVideosToPlaylist() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Add to playlist"), SLOT(showPlaylistDialog()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::addVideoDownloads() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Download"), SLOT(addVideoDownloads()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::addAudioDownloads() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Download"), SLOT(addAudioDownloads()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::queueVideos() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Add to queue"), SLOT(queueVideos()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::onItemClicked(const QModelIndex &index) {
    if (index.isValid()) {
        showVideoInfo(m_model->get(index.row()));
    }
}

void DailymotionPlaylistVideosWindow::showVideoInfo(QSharedPointer<VideoItem> video) {
    DailymotionVideoInfoWindow *window = new DailymotionVideoInfoWindow(m_session, video, this);
    window->show();
}

void DailymotionPlaylistVideosWindow::playVideo(const QModelIndex &index) {
    m_session->urlGrabber()->getDailymotionVideoUrl(index.data(AbstractVideoListModel::VideoIdRole).toString());
}

void DailymotionPlaylistVideosWindow::showUserChannel() {
    DailymotionChannelWindow *window = new DailymotionChannelWindow(m_session, m_playlist.data()->artistId(), this);
    window->show();
}

==> cutetube_1.3.2.tar.gz: cutetube-1.3.2/src/maemo5/dailymotionplaylistvideoswindow.cpp <==
#include "dailymotionplaylistvideoswindow.h"
#include "videolistdelegate.h"
#include "dailymotionvideoinfowindow.h"
#include "dailymotionchannelwindow.h"
#include "videoselectionwindow.h"
#include "dailymotionplaylistdialog.h"
#include <QMenuBar>
#include <QGridLayout>
#include <QScrollBar>

DailymotionPlaylistVideosWindow::DailymotionPlaylistVideosWindow(Session *session, QSharedPointer<PlaylistItem> playlist, QWidget *parent) :
    StackedWindow(session, parent),
    m_playlist(playlist),
    m_listView(new ListView(this)),
    m_model(new DailymotionVideoListModel(m_session, this)),
    m_addToFavouritesAction(menuBar()->addAction(tr("Add to favourites"), this, SLOT(addVideosToFavourites()))),
    m_addToPlaylistAction(menuBar()->addAction(tr("Add to playlist"), this, SLOT(addVideosToPlaylist()))),
    m_addToQueueAction(menuBar()->addAction(tr("Add to playback queue"), this, SLOT(queueVideos()))),
    m_videoDownloadAction(menuBar()->addAction(tr("Download"), this, SLOT(addVideoDownloads()))),
    m_audioDownloadAction(menuBar()->addAction(tr("Download (audio)"), this, SLOT(addAudioDownloads()))),
    m_contextMenu(new QMenu(this)),
    m_addToFavouritesContextAction(m_contextMenu->addAction(tr("Add to favourites"), this, SLOT(addVideoToFavourites()))),
    m_addToPlaylistContextAction(m_contextMenu->addAction(tr("Add to playlist"), this, SLOT(showPlaylistDialog()))),
    m_addToQueueContextAction(m_contextMenu->addAction(tr("Add to playback queue"), this, SLOT(queueVideo()))),
    m_videoDownloadContextAction(m_contextMenu->addAction(tr("Download"), this, SLOT(addVideoDownload()))),
    m_audioDownloadContextAction(m_contextMenu->addAction(tr("Download (audio)"), this, SLOT(addAudioDownload()))),
    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No videos found")), this)),
    m_titleLabel(new QLabel(QString("<p style='font-size:32px;'>%1</p>").arg(m_playlist.data()->title()))),
    m_descriptionLabel(new QLabel(m_playlist.data()->description().isEmpty() ? tr("No description") : m_playlist.data()->description(), this)),
    m_dateLabel(new QLabel(QString("%1 - %2").arg(m_playlist.data()->date()).arg(m_playlist.data()->artist()), this)),
    m_thumbnail(new ThumbnailLabel(this)),
    m_avatar(new ThumbnailLabel(this)),
    m_separator1(new SeparatorLabel(tr("Description"), this)),
    m_separator2(new SeparatorLabel(QString("-- %1").arg(tr("videos")), this)),
    m_scrollArea(new QScrollArea(this))
{
    setWindowTitle(tr("Playlist"));
    setCentralWidget(m_scrollArea);

    VideoListDelegate *delegate = new VideoListDelegate(m_listView);

    m_listView->setModel(m_model);
    m_listView->setItemDelegate(delegate);
    m_noResultsLabel->hide();
    m_descriptionLabel->setWordWrap(true);
    m_dateLabel->setWordWrap(true);

    QWidget *scrollWidget = new QWidget(m_scrollArea);
    QGridLayout *grid = new QGridLayout(scrollWidget);

    m_thumbnail->setInteractive(false);
    m_thumbnail->setFixedSize(160, 120);
    m_avatar->setFixedSize(60, 60);

    grid->setContentsMargins(0, 0, 0, 0);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Maximum), 0, 0);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Maximum), 1, 0);
    grid->addItem(new QSpacerItem(10, 10, QSizePolicy::Maximum), 3, 0);
    grid->addWidget(m_titleLabel, 0, 1, 1, 3, Qt::AlignTop);
    grid->addWidget(m_thumbnail, 1, 1, Qt::AlignTop);
    grid->addWidget(m_avatar, 1, 2, Qt::AlignTop);
    grid->addWidget(m_dateLabel, 1, 3, Qt::AlignTop);
    grid->addWidget(m_separator1, 2, 0, 1, 4);
    grid->addWidget(m_descriptionLabel, 3, 1, 1, 3);
    grid->addWidget(m_separator2, 4, 0, 1, 4);
    grid->addWidget(m_listView, 5, 0, 1, 4);

    m_scrollArea->setWidgetResizable(true);
    m_scrollArea->setWidget(scrollWidget);
    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);

    connect(m_model, SIGNAL(loadingChanged()), this, SLOT(onLoadingChanged()));
    connect(delegate, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
    connect(delegate, SIGNAL(play(QModelIndex)), this, SLOT(playVideo(QModelIndex)));
    connect(m_listView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
    connect(m_avatar, SIGNAL(clicked()), this, SLOT(showUserChannel()));

    m_model->getPlaylistVideos(m_playlist.data()->playlistId());

    setThumbnails();
    setMenuActions();
    onOrientationChanged();
}

void DailymotionPlaylistVideosWindow::setLandscapeLayout() {
    m_noResultsLabel->setFixedSize(m_scrollArea->size());
    m_scrollArea->widget()->setMaximumWidth(800);
}

void DailymotionPlaylistVideosWindow::setPortraitLayout() {
    m_noResultsLabel->setFixedSize(m_scrollArea->size());
    m_scrollArea->widget()->setMaximumWidth(480);
}

void DailymotionPlaylistVideosWindow::setThumbnails() {
    QImage thumbnail;

    if (m_model->rowCount() > 0) {
        thumbnail = m_session->thumbnailCache()->thumbnail(m_model->get(0).data()->thumbnailUrl());
    }

    QImage avatar = m_session->thumbnailCache()->thumbnail(m_playlist.data()->artistAvatarUrl(), QSize(60, 60));

    if ((thumbnail.isNull()) || (avatar.isNull())) {
        connect(m_session->thumbnailCache(), SIGNAL(thumbnailReady()), this, SLOT(setThumbnails()));
    }
    else {
        disconnect(m_session->thumbnailCache(), SIGNAL(thumbnailReady()), this, SLOT(setThumbnails()));
    }
    if (!thumbnail.isNull()) {
        m_thumbnail->setImage(thumbnail);
    }
    if (!avatar.isNull()) {
        m_avatar->setImage(avatar);
    }
}

void DailymotionPlaylistVideosWindow::setMenuActions() {
    bool signedIn = m_session->dailymotion()->userSignedIn();

    m_addToFavouritesAction->setEnabled(signedIn);
    m_addToPlaylistAction->setEnabled(signedIn);
}

void DailymotionPlaylistVideosWindow::onLoadingChanged() {
    toggleBusy(m_model->loading());
    m_noResultsLabel->setVisible((!m_model->loading()) && (m_model->rowCount() == 0));

    if (!m_model->loading()) {
        m_separator2->setText(QString("%1 %2").arg(m_model->rowCount()).arg(tr("videos")));

        if (m_model->rowCount() > 0) {
            m_listView->setFixedHeight(m_model->rowCount() * 150);
            setThumbnails();
        }
    }
}

void DailymotionPlaylistVideosWindow::addVideosToFavourites() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Add to favourites"), SLOT(addVideosToFavourites()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::addVideosToPlaylist() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Add to playlist"), SLOT(showPlaylistDialog()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::addVideoDownloads() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Download"), SLOT(addVideoDownloads()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::addAudioDownloads() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Download"), SLOT(addAudioDownloads()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::queueVideos() {
    VideoSelectionWindow *window = new VideoSelectionWindow(m_session, m_model, Services::Dailymotion, tr("Add to queue"), SLOT(queueVideos()), this);
    window->positionAtIndex(m_listView->indexAt(QPoint(0, m_scrollArea->verticalScrollBar()->value())));
    window->show();
}

void DailymotionPlaylistVideosWindow::showContextMenu(const QPoint &pos) {
    m_contextMenu->popup(pos, m_addToFavouritesContextAction);
}

void DailymotionPlaylistVideosWindow::addVideoToFavourites() {
    m_session->dailymotion()->addToFavourites(m_model->get(m_listView->currentIndex().row()));
}

void DailymotionPlaylistVideosWindow::showPlaylistDialog() {
    DailymotionPlaylistDialog *dialog = new DailymotionPlaylistDialog(m_session, this);
    dialog->open();

    connect(dialog, SIGNAL(playlistChosen(QString)), this, SLOT(addVideoToPlaylist(QString)));
    connect(dialog, SIGNAL(addToNewPlaylist(NewPlaylist)), this, SLOT(addVideoToNewPlaylist(NewPlaylist)));
}

void DailymotionPlaylistVideosWindow::addVideoToPlaylist(const QString &id) {
    m_session->dailymotion()->addToPlaylist(m_model->get(m_listView->currentIndex().row()), id);
}

void DailymotionPlaylistVideosWindow::addVideoToNewPlaylist(const NewPlaylist &playlist) {
    m_session->dailymotion()->createPlaylist(playlist, m_model->get(m_listView->currentIndex().row()));
}

void DailymotionPlaylistVideosWindow::addVideoDownload() {
    m_session->transferManager()->addDownloadTransfer(m_model->get(m_listView->currentIndex().row()));
}

void DailymotionPlaylistVideosWindow::addAudioDownload() {
    m_session->transferManager()->addDownloadTransfer(m_model->get(m_listView->currentIndex().row()), true);
}

void DailymotionPlaylistVideosWindow::queueVideo() {
    m_session->playbackQueue()->addVideo(m_model->get(m_listView->currentIndex().row()));
}

void DailymotionPlaylistVideosWindow::onItemClicked(const QModelIndex &index) {
    if (index.isValid()) {
        showVideoInfo(m_model->get(index.row()));
    }
}

void DailymotionPlaylistVideosWindow::showVideoInfo(QSharedPointer<VideoItem> video) {
    DailymotionVideoInfoWindow *window = new DailymotionVideoInfoWindow(m_session, video, this);
    window->show();
}

void DailymotionPlaylistVideosWindow::playVideo(const QModelIndex &index) {
    m_session->urlGrabber()->getDailymotionVideoUrl(index.data(AbstractVideoListModel::VideoIdRole).toString());
}

void DailymotionPlaylistVideosWindow::showUserChannel() {
    DailymotionChannelWindow *window = new DailymotionChannelWindow(m_session, m_playlist.data()->artistId(), this);
    window->show();
}
